# Filter

Filter commands are used to create real-time filters of output request data.

## Create filters

### In Mdb

```{eval-rst}
.. autoclass:: abaqus.Filter.FilterModel.FilterModel
    :members:
    :show-inheritance:

    .. autoclasstoc::
```

### In Odb

```{eval-rst}
.. autoclass:: abaqus.Filter.FilterOdb.FilterOdb
    :members:
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Filter
        :recursive:
        :exclude: FilterModel, FilterOdb

    .. placeholder for empty members
```
